** ***************************************************************************************************************
*****************************************************************************************************************
*****************************************************************************************************************
*****************************************************************************************************************
/***
Stella Babalola
Johns Hopkins University
Baltimore, MD
November 2017

This .do file implements Stata procedures for the analysis reported in the paper on north-south differentials in 
contracetive use in Nigeria by Stella Babalola and Olamide Oyenubi. The data cae from the Nigeria 2013 Demographic 
and Health Survey, downloadable from www.dhsprogram.com. This .do file allows you to create relevant variables

use NGIR6AFL.DTA
***Create sample weight and survey set your data
gen samplewght_all=v005/1000000

gen newstrata=v022
replace newstrata=59 if v022==60
svyset [pw= samplewght_all2], psu(v021) strata(newstrata)

*** Create new variables to use in the models from existing ones
gen north=v024<4 
gen FPonradio=v384a==1
gen FPontv=v384b==1
gen FPonnews=v384c==1
gen educ=v106
label value educ V106
gen working=v714==1
gen urban=v025==1
gen afraidofhusband=d129!=0
replace afraidofhusband=. if d129==.
gen husbeducinyears=v715
replace husbeducinyears=. if v715>20
gen educinyears=v133
replace educinyears=. if v133>20
replace educin=5 if educ==1&educin==.
replace educin=11 if educ==2&educin==.
replace educin=15 if educ==3&educin==.
gen educdiff= husbeducinyears- educinyears
gen educdiff5plus=educdiff>4
replace educdiff5plus=. if educdiff==.
gen ageinyears=v012
gen husbage=v730
replace husbage=. if husbage==199
gen agediff=husbage-ageinyears
gen agediff10plus=agediff>9
gen decide743a=v743a<3
gen decide743b=v743b<3
gen decide743d=v743d<3
egen decisionscore=rsum(decide743*)
gen hidecision=decisionscore>0
replace hidecision=. if decisionscore==.
gen everd105a=d105a!=0
gen everd105b=d105b!=0
gen everd105c=d105c!=0
gen everd105d=d105d!=0
gen everd105e=d105e!=0
gen everd105f=d105f!=0
egen numberofIPV_physical=rsum(everd105*)
replace numberofIPV_physical=. if d105a==.
gen anyphysical_violence= numberofIPV_physical>0
replace anyphysical_violence=. if numberofIPV_physical==.
	foreach var of varlist v304_01- v304_07 v304_11 v304_13- v304_18 {
		gen byte `var'_kn=0
		replace `var'_kn=1 if `var'==1
		}
egen modernmethodskn=rsum (v304*kn)
gen idealnbchildren=v613
replace idealnbchildren=. if v613>30
gen wifeaskhusb_usecondom=v822==1
gen effic_askpartnercondom=v850b==1
gen moslem=v130==3
sort v021
by v021: gen clustersize=_N
egen summoslem=sum(moslem), by(v021)
gen nsmmoslem=(summoslem-moslem)/(clustersize-1)
gen marriedorcohabiting=v501==1|v501==2
gen usemodern=v312
recode usemodern (1/7=1) (11/18=1)
tab usemodern
recode usemodern (8/10=0)
tab usemodern
gen usemodern2=usemodern
replace usemodern=0 if v312==13|v312==18
label variable usemodern "using modern excluding LAM and SDM”
label variable usemodern2 "using modern including LAM and SDM”

**** Weighted avearages
mean usemodern if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)
mean FPonradio if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)
mean FPontv if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)
mean FPonnews if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)
mean v012 if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)
mean v201 if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)
proportion educ if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)
proportion v190 if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)
mean working if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)
mean urban if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)
mean afraidof if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)
mean educdiff5 if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)
mean agediff10 if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)
proportion v621 if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)
mean hidecision if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)
mean anyphysical_ if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)
mean modernmethodskn if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)
mean idealnbchildren if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)
mean wifeask if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)
mean effic_ask if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)
mean nsmmo if v621!=9&v602!=5&marriedorcohabiting==1 [pw= samplewght_al], over(north)


*** Estimate the non-linear decomposition models
xi:fairlie usemodern (media: FPonradio FPontv FPonnews) (sociodemog: v012 v201 ) (socioeconm: i.educ  i.v190 working urban) (power: afraidof educdiff5plus agediff10plus i.v621  hidecision) (ipv: anyphysical_violence ) (ideation: modernmethodskn idealnbchildren wifeaskhusb_usecondom effic_askpartnercondom) (culture: nsmmoslem) if v621!=9&v602!=5&marriedorcohabiting==1 [pw=samplewght_all], by(north) ro reps(1000) pooled
xi:fairlie usemodern v012 v201 educinyears v191 working urban FPonradio FPontv FPonnews modernmethodskn idealnbchildren wifeaskhusb_usecondom effic_askpartnercondom afraidof educdiff5plus agediff10plus husbandwantmo hidecision anyphysical_violence nsmmoslem if v621!=9&v602!=5&marriedorcohabiting==1  [pw=samplewght_all], by(north) ro reps(1000) pooled

